import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { useDataMap } from './useDataMap';
import { useDataViews } from './useDataViews';
import { Marks } from './Marks';
import { scaleLinear, extent, scaleSqrt, max } from 'd3';

const width = 960;
const height = 500;

const App = () => {
  const mapData = useDataMap();
  const viewData = useDataViews();
  
  if (!mapData || !viewData) {
    return <pre>Loading...</pre>;
  }
  
  
  const lng = d => d.Lng;
  const lat = d => d.Lat;
  const country = d => d.Countries;
  const views = d => d.Views;
  const sizeValue = d => d.views;
  const maxRadius = 4
  const sizeScale = scaleSqrt()
  .domain([0, max(viewData, sizeValue)])
  .range([0, maxRadius] )

  
  return (
		<svg width={width} height={height}>
      <Marks 
        mapData={mapData}
        viewData={viewData}
        lng={lng} 
        lat={lat} 
        views={views}
        country={country}
        sizeScale={sizeScale}
        sizeValue={sizeValue}
        />
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
